@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.27+6" },
-            { "jdk", "11.0.27" },
-            { "release", "11.0.27" },
+            { "full", "17.0.4.1+1" },
+            { "jdk", "17.0.4.1" },
+            { "release", "17.0.4.1" },
         };
     }
 }
